==============================================
Tempest plugin for ironic and ironic-inspector
==============================================

This repository contains a Tempest_ plugin for OpenStack `Bare Metal`_ and
`Bare Metal Introspection`_ projects.

* Free software: Apache license
* Documentation: https://docs.openstack.org/ironic-tempest-plugin
* Source: https://opendev.org/openstack/ironic-tempest-plugin
* Bugs: https://storyboard.openstack.org/#!/project/951

.. _Tempest: https://docs.openstack.org/tempest/latest/
.. _Bare Metal: https://docs.openstack.org/ironic/latest/
.. _Bare Metal Introspection: https://docs.openstack.org/ironic-inspector/latest/
